@@ -9,7 +9,7 @@ BEGIN {
 use strict;
 use warnings;
 
-our $VERSION = '0.1907';
+our $VERSION = '0.1908';
 
 1;
 
@@ -25,7 +25,7 @@ Task::MusicBundle - MIDI and music creation modules
 
 =head1 VERSION
 
-version 0.1907
+version 0.1908
 
 =head1 SYNOPSIS
 
@@ -108,10 +108,6 @@ L<Music::Guidonian>
 
 L<Music::Harmonics>
 
-L<Music::Interval::Barycentric>
-
-L<Music::Intervals>
-
 L<Music::MelodicDevice::Inversion>
 
 L<Music::MelodicDevice::Ornamentation>
@@ -120,6 +116,8 @@ L<Music::MelodicDevice::Transposition>
 
 L<Music::NeoRiemannianTonnetz>
 
+L<Music::Note>
+
 L<Music::Note::Frequency>
 
 L<Music::Note::Role::Operators>
